@@ -1,8 +1,9 @@
 import numpy as np
-from scipy.stats import norm
 from patsy import dmatrices, build_design_matrices
 
 class LM(object):
+    """An example ordinary least squares linear model class, analogous to R's
+    lm() function. Don't use this in real life, it isn't properly tested."""
     def __init__(self, formula_like, data={}):
         y, x = dmatrices(formula_like, data, 1)
         self.nobs = x.shape[0]
@@ -29,8 +30,9 @@ class LM(object):
         (new_y, new_x) = build_design_matrices([self._y_design_info.builder,
                                                 self._x_design_info.builder],
                                                new_data)
-        print new_x
-        print self.betas
         new_pred = np.dot(new_x, self.betas)
-        sigma = np.sqrt(self.rss / self.nobs)
-        return np.log(norm.pdf(new_y, loc=new_pred, scale=sigma))
+        sigma2 = self.rss / self.nobs
+        # It'd be more elegant to use scipy.stats.norm.logpdf here, but adding
+        # a dependency on scipy makes the docs build more complicated:
+        Z = -0.5 * np.log(2 * np.pi * sigma2)
+        return Z + -0.5 * (new_y - new_x) ** 2/sigma2
